@@ -1,7 +1,9 @@
-# 	$Id: ObjScanner.pm,v 2.10 2004/07/30 11:57:35 domi Exp $	
+# 	$Id: ObjScanner.pm,v 2.12 2007-10-09 11:21:08 domi Exp $	
 
 package Tk::ObjScanner;
 
+require 5.006;
+
 use strict;
 use warnings ;
 use Scalar::Util qw(weaken isweak);
@@ -64,7 +66,7 @@ use Data::Dumper;
 our @ISA = qw(Tk::Derived Tk::Frame);
 *isa = \&UNIVERSAL::isa;
 
-our $VERSION = sprintf "%d.%03d", q$Revision: 2.10 $ =~ /(\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%03d", q$Revision: 2.12 $ =~ /(\d+)\.(\d+)/;
 
 Tk::Widget->Construct('ObjScanner');
 
@@ -143,9 +145,14 @@ sub Populate
     my $display_view_pseudo_button = defined $args->{'-view_pseudo'} ||
       defined $args->{view_pseudo} ? 0 : 1;
 
-   my $view_pseudo = delete $args->{'-view_pseudo'} || 
+    my $view_pseudo = delete $args->{'-view_pseudo'} || 
       delete $args->{'view_pseudo'} || 0;
 
+    # override option for feature not supported by Perl 5.09 and later
+    if ($] >= 5.009) {
+	$view_pseudo = 0 ;
+    }
+
     croak "Missing caller argument in ObjScanner\n" 
       unless defined  $cw->{chief};
 
@@ -739,7 +746,8 @@ parameter is ignored if show_menu is unset.
 
 =item C<-view_pseudo>
 
-If set, will interpret pseudo hashes as hash (default 0)
+If set, will interpret pseudo hashes as hash (default 0). This option
+is disabled for Perl 5.09 and later.
 
 =item C<-show_tied>
 
@@ -806,7 +814,7 @@ The idea to use B::Deparse to view code ref.
 
 Dominique Dumont, dominique.dumont@hp.com
 
-Copyright (c) 1997-2004 Dominique Dumont. All rights reserved.
+Copyright (c) 1997-2004,2007 Dominique Dumont. All rights reserved.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
